/***********************************************************************/
/***********************************************************************/
/**                                                              
/** Copyright (C) BEKA Associates Ltd (2005). All Rights Reserved    
/**                                                                   
/** Device        : BA488CF                              
/** Communication : PROFIBUS PA                                       
/** Description   : PROFIBUS PA EDDL for BA488CF  		 
/**  		    Graphics Transducer Block Varaibles and Commands            
/**
/** Histrory      : M.P.Wilson 04/03/2005 first created
/**		    M.P.Wilson 08/03/2005 BEKA Variables added
/**                 M.P.Wilson 03/05/2005 Read Batch Qty Added 
/**		    M.P.WIlson 04/05/2005 Online Temperature Added
/**
/***********************************************************************/
/***********************************************************************/

/*******************************************************************************/
/*****	VARIABLES BATCH Transducer Block
/*******************************************************************************/

VARIABLE batch_BLK_RESERVE
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
  	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE batch_BLK_OBJECT
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	3,	[blk_block_object_TRANSDUCER]	}
	}
	HANDLING	READ;
}

VARIABLE batch_BLK_PARENT_CLASS
{
	LABEL		[blk_parent_class];
	HELP		[TB_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{ 0xf5, "Transducer" }
	}
	HANDLING	READ;
}

VARIABLE batch_BLK_CLASS
{
	LABEL		[blk_class];
	HELP		[TB_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	250,	[not_used] 					},
		{	251,	[none]						},
		{	252,	[unknown]					},
		{	253,	[special]					}
	}
	HANDLING	READ;
}

VARIABLE batch_BLK_DD_REFRENCE
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE batch_BLK_DD_REV
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE batch_BLK_PROFILE
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x4002;
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE batch_BLK_PROFILE_REV
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0300;
		{	0x0300,	"3.0"	}
	}
	HANDLING	READ;
}

VARIABLE batch_BLK_EXECUTION_TIME
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE batch_BLK_NUM_PARAMETERS
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE batch_BLK_INDEX_VIEW_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE batch_BLK_NUM_VIEW_LISTS
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE batch_STATIC_REVISION
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE batch_TAG_DESCRIPTION
{
	LABEL		[tag_desc];		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE batch_STRATEGY
{
	LABEL		[strategy];		
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE batch_ALERT_KEY
{
	LABEL		[alert_key];		
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE batch_TARGET_MODE
{
	LABEL	  	[target_mode];		
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	   DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				}
		{	0x80,	[mode_OUT_OF_SERVICE]	}

	}
	HANDLING	READ & WRITE;
}

VARIABLE batch_ACTUAL_MODE
{
	LABEL		[actual_mode];		
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0x08 ;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE batch_PERMITTED_MODE
{
	LABEL		[permitted_mode];		
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
//		DEFAULT_VALUE	0x88;
		DEFAULT_VALUE	0x08;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE batch_NORMAL_MODE
{
	LABEL		[normal_mode];		
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE batch_CURRENT_STATE_ALARM_SUM
{
	LABEL		[current_state_alarm_sum];		
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE batch_UNACKNOWLEDGED_STATE_ALARM_SUM
{
	LABEL		[unacknowledged_state_alarm_sum];		
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE batch_UNREPORTED_STATE_ALARM_SUM
{
	LABEL		[unreported_state_alarm_sum];		
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE batch_DISABLED_STATE_ALARM_SUM
{
	LABEL		[disabled_state_alarm_sum];		
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE batch_stop
{
	LABEL 	 "Stop";
	HELP 	 "Stops a batch controller";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 ENUMERATED (1)
	{
	        DEFAULT_VALUE 0;
	        {	0, "False"},
	        {	1, "True"}
	}
	HANDLING READ & WRITE;
}

VARIABLE batch_reset
{
	LABEL 	 "RESET";
	HELP 	 "Resets a batch controller";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 ENUMERATED (1)
	{
	        DEFAULT_VALUE 0;
	        {	0, "False"},
	        {	1, "True"}
	}
	HANDLING READ & WRITE;
}		

VARIABLE batch_start
{
	LABEL 	 "Start";
	HELP 	 "Starts a batch controller";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 ENUMERATED (1)
	{
	        DEFAULT_VALUE 0;
	        {	0, "False"},
	        {	1, "True"}
	}
	HANDLING READ & WRITE;
}		

VARIABLE batch_state_status
{
	LABEL 	 "Batcher State Status";
	HELP 	 "Reads the Current Batcher Status";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 UNSIGNED_INTEGER (1);
	HANDLING READ;
}		

VARIABLE batch_state_description
{
	LABEL 	 "Batcher State Description";
	HELP 	 "Reads the Current Batcher State Description";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 ASCII (20);
	HANDLING READ;
}		

VARIABLE batch_setpoint
{
	LABEL 	 "Batcher Setpoint";
	HELP 	 "Reads and sets the setpoint";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 FLOAT;
	HANDLING READ & WRITE;
}		

VARIABLE batch_batched_quantity
{
	LABEL 	 "Current Batch Quantity";
	HELP 	 "Reads the current batch quantity";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 FLOAT;
	HANDLING READ;
}		

VARIABLE batch_last_batch
{
	LABEL 	 "Last Batch Size";
	HELP 	 "Reads the last batch quantity";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 FLOAT;
	HANDLING READ;
}		

VARIABLE batch_name
{
	LABEL 	 "Batch Name";
	HELP 	 "Reads and sets the batch name";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 ASCII (16);
	HANDLING READ & WRITE;
}		

VARIABLE batch_start_permissive
{
	LABEL 	 "Start Permissive";
	HELP 	 "Controls whether a batch controller is allowed to start";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 ENUMERATED (1)
	{
	        DEFAULT_VALUE 0;
	        {	0, "False"},
	        {	1, "True"}
	}
	HANDLING READ & WRITE;
}		

VARIABLE batch_rate  /* Use as temperature in a text display */
{
	LABEL 	 "Unit Temperature";
	HELP 	 "Returns value of Display Internal Temperature";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 FLOAT;
	HANDLING READ;
}		

VARIABLE batch_rate_timebase
{
	LABEL 	 "Current rate timbase";
	HELP 	 "Returns value of rate timebase";
	CLASS 	 CONTAINED & DYNAMIC;
	TYPE	 FLOAT;
	HANDLING READ;
}		

/**********************************************************************/
/*****	Batch Transducer block commands
/**********************************************************************/

COMMAND read_batch_BLOCK
{
	BLOCK batch_BLOCK;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_BLK_RESERVE,
			batch_BLK_OBJECT,
			batch_BLK_PARENT_CLASS,
			batch_BLK_CLASS,
			batch_BLK_DD_REFRENCE,
			batch_BLK_DD_REV,
			batch_BLK_PROFILE,
			batch_BLK_PROFILE_REV,
			batch_BLK_EXECUTION_TIME,
			batch_BLK_NUM_PARAMETERS,
			batch_BLK_INDEX_VIEW_1,
			batch_BLK_NUM_VIEW_LISTS
		}
	}
}

COMMAND read_batch_STATIC_REVISION
{
	BLOCK batch_BLOCK;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_STATIC_REVISION
		}
	}
}

COMMAND read_batch_TAG_DESCRIPTION
{
	BLOCK batch_BLOCK;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_TAG_DESCRIPTION
		}
	}
}

COMMAND write_batch_TAG_DESCRIPTION
{
	BLOCK batch_BLOCK;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			batch_TAG_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_batch_STRATEGY
{
	BLOCK batch_BLOCK;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_STRATEGY
		}
	}
}

COMMAND write_batch_STRATEGY
{
	BLOCK batch_BLOCK;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			batch_STRATEGY
		}
		REPLY
		{
		}
	}
}

COMMAND read_batch_ALERT_KEY
{
	BLOCK batch_BLOCK;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_ALERT_KEY
		}
	}
}

COMMAND write_batch_ALERT_KEY
{
	BLOCK batch_BLOCK;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			batch_ALERT_KEY
		}
		REPLY
		{
		}
	}
}

COMMAND read_batch_TARGET_MODE
{
	BLOCK batch_BLOCK;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_TARGET_MODE
		}
	}
}

COMMAND write_batch_TARGET_MODE
{
	BLOCK batch_BLOCK;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			batch_TARGET_MODE
		}
		REPLY
		{
		}
	}
}

COMMAND read_batch_MODE
{
	BLOCK batch_BLOCK;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_ACTUAL_MODE,
			batch_PERMITTED_MODE,
			batch_NORMAL_MODE
		}
	}
}

COMMAND read_batch_ALARM_SUM
{
	BLOCK batch_BLOCK;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_CURRENT_STATE_ALARM_SUM,
			batch_UNACKNOWLEDGED_STATE_ALARM_SUM,
			batch_UNREPORTED_STATE_ALARM_SUM,
			batch_DISABLED_STATE_ALARM_SUM
		}
	}
}

COMMAND read_batch_stop
{
	BLOCK batch_BLOCK;
	INDEX	8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_stop
		}
		
	}
}

COMMAND write_batch_stop
{
	BLOCK batch_BLOCK;
	INDEX	8;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_stop
		}
		
	}
}

COMMAND read_batch_start
{
	BLOCK batch_BLOCK;
	INDEX	9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_start
		}
		
	}
}

COMMAND write_batch_start
{
	BLOCK batch_BLOCK;
	INDEX	9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_start
		}
		
	}
}

COMMAND read_batch_reset
{
	BLOCK batch_BLOCK;
	INDEX	10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_reset
		}
		
	}
}

COMMAND write_batch_reset
{
	BLOCK batch_BLOCK;
	INDEX	10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_reset
		}
		
	}
}

COMMAND read_batch_state
{
	BLOCK batch_BLOCK;
	INDEX	11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_state_status,
			batch_state_description
		}
		
	}
}

COMMAND read_batch_setpoint
{
	BLOCK batch_BLOCK;
	INDEX	12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_setpoint
		}
		
	}
}

COMMAND write_batch_setpoint
{
	BLOCK batch_BLOCK;
	INDEX	12;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_setpoint
		}
		
	}
}

COMMAND read_batch_setpoint
{
	BLOCK batch_BLOCK;
	INDEX	12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_setpoint
		}
		
	}
}

COMMAND read_batch_batched_quantity
{
	BLOCK batch_BLOCK;
	INDEX	13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_batched_quantity
		}
		
	}
}

COMMAND read_batch_last_batch
{
	BLOCK batch_BLOCK;
	INDEX	14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_last_batch
		}
		
	}
}

COMMAND write_batch_last_batch
{
	BLOCK batch_BLOCK;
	INDEX	14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_last_batch
		}
		
	}
}

COMMAND read_batch_name
{
	BLOCK batch_BLOCK;
	INDEX	15;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_name
		}
		
	}
}

COMMAND write_batch_name
{
	BLOCK batch_BLOCK;
	INDEX	15;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_name
		}
		
	}
}

COMMAND read_start_permissive
{
	BLOCK batch_BLOCK;
	INDEX	16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_start_permissive
		}
		
	}
}

COMMAND write_batch_start_permissive
{
	BLOCK batch_BLOCK;
	INDEX	16;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_start_permissive
		}
		
	}
}

COMMAND read_batch_rate
{
	BLOCK batch_BLOCK;
	INDEX	17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_rate
		}
		
	}
}

COMMAND read_batch_rate_timebase
{
	BLOCK batch_BLOCK;
	INDEX	18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			batch_rate_timebase
		}
		
	}
}

/**********************************************************************/
/*****	Table: Information - Specialist and Maintenance 
/**********************************************************************/

MENU Table_S_batch
{
	LABEL		[beka_batch];
	ITEMS
	{
        	Table_batch_tbblock,
        	batch_STATIC_REVISION,
        	batch_TAG_DESCRIPTION,
        	batch_STRATEGY,
        	batch_ALERT_KEY,
        	batch_TARGET_MODE,
        	Table_batch_modeblock,
        	Table_batch_alarmblock,
        	batch_stop,
        	batch_reset,
        	batch_start,
        	Table_batch_state,
        	batch_setpoint,
        	batch_batched_quantity,
        	batch_last_batch,
        	batch_name,
        	batch_start_permissive,
        	batch_rate,
        	batch_rate_timebase	       	
	}
}

MENU Table_M_batch
{
	LABEL		[beka_batch];
	ITEMS
	{
        	Table_batch_tbblock,
        	batch_STATIC_REVISION 	(READ_ONLY),
        	batch_TAG_DESCRIPTION 	(READ_ONLY),
        	batch_STRATEGY 		(READ_ONLY),
        	batch_ALERT_KEY 	(READ_ONLY),
        	batch_TARGET_MODE 	(READ_ONLY),
        	Table_batch_modeblock,
        	Table_batch_alarmblock
        	batch_stop		(READ_ONLY),
        	batch_reset		(READ_ONLY),
        	batch_start		(READ_ONLY),
        	Table_batch_state,
        	batch_setpoint		(READ_ONLY),
        	batch_batched_quantity,
        	batch_last_batch,
        	batch_name		(READ_ONLY),
        	batch_start_permissive	(READ_ONLY),
        	batch_rate,
        	batch_rate_timebase	       	
	}
}

MENU Table_batch_tbblock
{
	LABEL		[beka_block_characteristics];
	ITEMS
	{
		batch_BLK_RESERVE,
		batch_BLK_OBJECT,
		batch_BLK_PARENT_CLASS,
		batch_BLK_CLASS,
		batch_BLK_DD_REFERENCE,
		batch_BLK_DD_REV,
		batch_BLK_PROFILE,
		batch_BLK_PROFILE_REV,
		batch_BLK_EXECUTION_TIME,
		batch_BLK_NUM_PARAMETERS,
		batch_BLK_INDEX_VIEW_1,
		batch_BLK_NUM_VIEW_LISTS
	}
}

MENU Table_batch_modeblock
{
	LABEL		[beka_mode_block];
	ITEMS
	{
		batch_ACTUAL_MODE,
		batch_PERMITTED_MODE,
		batch_NORMAL_MODE,
	}
}


MENU Table_batch_alarmblock
{
	LABEL		[beka_alarm_summary];
	ITEMS
	{
		batch_CURRENT_STATE_ALARM_SUM,
		batch_UNACKNOWLEDGED_STATE_ALARM_SUM,
		batch_UNREPORTED_STATE_ALARM_SUM,
		batch_DISABLED_STATE_ALARM_SUM
	}
}

MENU Table_batch_state
{
	LABEL		[beka_batch_state];
	ITEMS
	{
		batch_batch_state_description,
		batch_batch_state_status
	}
}

MENU batch_temperature
{
	LABEL		"Temperature";
	ITEMS
	{
		batch_rate
	}
}
